diff --git a/gcc/ada/sigtramp-vxworks-target.h b/gcc/ada/sigtramp-vxworks-target.h
index 153426eeda8..ae6b9cb8bbb 100644
--- a/gcc/ada/sigtramp-vxworks-target.h
+++ b/gcc/ada/sigtramp-vxworks-target.h
@@ -149,7 +149,7 @@
 
    In general:
    There is no unique numbering for the x86 architecture.  It's parameterized
-   by DWARF_FRAME_REGNUM, which is DBX_REGISTER_NUMBER except for Windows, and
+   by DWARF_FRAME_REGNUM, which is DEBUGGER_REGISTER_NUMBER except for Windows, and
    the latter depends on the platform.
 */
 
diff --git a/gcc/config/aarch64/aarch64-protos.h b/gcc/config/aarch64/aarch64-protos.h
index 19c9d3cb179..48fd2a8af6e 100644
--- a/gcc/config/aarch64/aarch64-protos.h
+++ b/gcc/config/aarch64/aarch64-protos.h
@@ -878,7 +878,7 @@ rtx aarch64_simd_vect_par_cnst_half (machine_mode, int, bool);
 rtx aarch64_gen_stepped_int_parallel (unsigned int, int, int);
 bool aarch64_stepped_int_parallel_p (rtx, int);
 rtx aarch64_tls_get_addr (void);
-unsigned aarch64_dbx_register_number (unsigned);
+unsigned aarch64_debugger_register_number (unsigned);
 unsigned aarch64_trampoline_size (void);
 void aarch64_asm_output_labelref (FILE *, const char *);
 void aarch64_cpu_cpp_builtins (cpp_reader *);
diff --git a/gcc/config/aarch64/aarch64.cc b/gcc/config/aarch64/aarch64.cc
index 4b486aeea90..31f47a04a9e 100644
--- a/gcc/config/aarch64/aarch64.cc
+++ b/gcc/config/aarch64/aarch64.cc
@@ -3357,7 +3357,7 @@ aarch64_reassociation_width (unsigned opc, machine_mode mode)
 
 /* Provide a mapping from gcc register numbers to dwarf register numbers.  */
 unsigned
-aarch64_dbx_register_number (unsigned regno)
+aarch64_debugger_register_number (unsigned regno)
 {
    if (GP_REGNUM_P (regno))
      return AARCH64_DWARF_R0 + regno - R0_REGNUM;
diff --git a/gcc/config/aarch64/aarch64.h b/gcc/config/aarch64/aarch64.h
index 80cfe4b7407..19f251918bd 100644
--- a/gcc/config/aarch64/aarch64.h
+++ b/gcc/config/aarch64/aarch64.h
@@ -631,12 +631,12 @@
 #define DWARF_FRAME_REGISTERS           (DWARF_ALT_FRAME_RETURN_COLUMN + 1)
 
 
-#define DBX_REGISTER_NUMBER(REGNO)	aarch64_dbx_register_number (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO)	aarch64_debugger_register_number (REGNO)
 /* Provide a definition of DWARF_FRAME_REGNUM here so that fallback unwinders
    can use DWARF_ALT_FRAME_RETURN_COLUMN defined below.  This is just the same
    as the default definition in dwarf2out.cc.  */
 #undef DWARF_FRAME_REGNUM
-#define DWARF_FRAME_REGNUM(REGNO)	DBX_REGISTER_NUMBER (REGNO)
+#define DWARF_FRAME_REGNUM(REGNO)	DEBUGGER_REGISTER_NUMBER (REGNO)
 
 #define DWARF_FRAME_RETURN_COLUMN	DWARF_FRAME_REGNUM (LR_REGNUM)
 
diff --git a/gcc/config/alpha/alpha.h b/gcc/config/alpha/alpha.h
index c01353a3bf2..24bd5455c8c 100644
--- a/gcc/config/alpha/alpha.h
+++ b/gcc/config/alpha/alpha.h
@@ -638,7 +638,7 @@ enum reg_class {
    can use DWARF_ALT_FRAME_RETURN_COLUMN defined below.  This is just the same
    as the default definition in dwarf2out.cc.  */
 #undef DWARF_FRAME_REGNUM
-#define DWARF_FRAME_REGNUM(REG) DBX_REGISTER_NUMBER (REG)
+#define DWARF_FRAME_REGNUM(REG) DEBUGGER_REGISTER_NUMBER (REG)
 
 /* Before the prologue, RA lives in $26.  */
 #define INCOMING_RETURN_ADDR_RTX  gen_rtx_REG (Pmode, 26)
diff --git a/gcc/config/arc/arc.cc b/gcc/config/arc/arc.cc
index 064790bf396..688605fd3e9 100644
--- a/gcc/config/arc/arc.cc
+++ b/gcc/config/arc/arc.cc
@@ -1885,7 +1885,7 @@ arc_init_reg_tables (void)
    Because mlo / mhi form a 64 bit value, we use different gcc internal
    register numbers to make them form a register pair as the gcc internals
    know it.  mmid gets number 57, if still available, and mlo / mhi get
-   number 58 and 59, depending on endianness.  We use DBX_REGISTER_NUMBER
+   number 58 and 59, depending on endianness.  We use DEBUGGER_REGISTER_NUMBER
    to map this back.  */
   char rname56[5] = "r56";
   char rname57[5] = "r57";
diff --git a/gcc/config/arc/arc.h b/gcc/config/arc/arc.h
index 0cb560b8a38..c9209d69f9b 100644
--- a/gcc/config/arc/arc.h
+++ b/gcc/config/arc/arc.h
@@ -1340,8 +1340,8 @@ do { \
 #undef PREFERRED_DEBUGGING_TYPE
 #define PREFERRED_DEBUGGING_TYPE DWARF2_DEBUG
 
-/* How to renumber registers for dbx and gdb.  */
-#define DBX_REGISTER_NUMBER(REGNO)				\
+/* How to renumber registers for gdb.  */
+#define DEBUGGER_REGISTER_NUMBER(REGNO)				\
   ((TARGET_MULMAC_32BY16_SET && (REGNO) >= 56 && (REGNO) <= 57) \
    ? ((REGNO) ^ !TARGET_BIG_ENDIAN)				\
    : (TARGET_MUL64_SET && (REGNO) >= 57 && (REGNO) <= 58)	\
diff --git a/gcc/config/arm/arm-protos.h b/gcc/config/arm/arm-protos.h
index f8aabbdae37..342833a1061 100644
--- a/gcc/config/arm/arm-protos.h
+++ b/gcc/config/arm/arm-protos.h
@@ -45,7 +45,7 @@ extern HOST_WIDE_INT arm_compute_initial_elimination_offset (unsigned int,
 							     unsigned int);
 extern HOST_WIDE_INT thumb_compute_initial_elimination_offset (unsigned int,
 							       unsigned int);
-extern unsigned int arm_dbx_register_number (unsigned int);
+extern unsigned int arm_debugger_register_number (unsigned int);
 extern void arm_output_fn_unwind (FILE *, bool);
 
 extern rtx arm_expand_builtin (tree exp, rtx target, rtx subtarget
diff --git a/gcc/config/arm/arm.cc b/gcc/config/arm/arm.cc
index eca99c904ba..359dd86212f 100644
--- a/gcc/config/arm/arm.cc
+++ b/gcc/config/arm/arm.cc
@@ -29568,7 +29568,7 @@ arm_shift_truncation_mask (machine_mode mode)
 /* Map internal gcc register numbers to DWARF2 register numbers.  */
 
 unsigned int
-arm_dbx_register_number (unsigned int regno)
+arm_debugger_register_number (unsigned int regno)
 {
   if (regno < 16)
     return regno;
diff --git a/gcc/config/arm/arm.h b/gcc/config/arm/arm.h
index f479540812a..54712ebc690 100644
--- a/gcc/config/arm/arm.h
+++ b/gcc/config/arm/arm.h
@@ -1062,7 +1062,7 @@ extern const int arm_arch_cde_coproc_bits[];
 /* VFP (VFP3) adds 32 (64) + 1 VFPCC.  */
 #define FIRST_PSEUDO_REGISTER   107
 
-#define DBX_REGISTER_NUMBER(REGNO) arm_dbx_register_number (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) arm_debugger_register_number (REGNO)
 
 /* Value should be nonzero if functions must have frame pointers.
    Zero means the frame pointer need not be set up (and parms may be accessed
diff --git a/gcc/config/bfin/bfin.h b/gcc/config/bfin/bfin.h
index a442a81f90c..83554d68641 100644
--- a/gcc/config/bfin/bfin.h
+++ b/gcc/config/bfin/bfin.h
@@ -1094,8 +1094,8 @@ extern rtx bfin_cc_rtx, bfin_rets_rtx;
 /* This works for GAS and some other assemblers.  */
 #define SET_ASM_OP              ".set "
 
-/* DBX register number for a given compiler register number */
-#define DBX_REGISTER_NUMBER(REGNO)  (REGNO) 
+/* Debugger register number for a given compiler register number */
+#define DEBUGGER_REGISTER_NUMBER(REGNO)  (REGNO) 
 
 #define SIZE_ASM_OP     "\t.size\t"
 
diff --git a/gcc/config/c6x/c6x.cc b/gcc/config/c6x/c6x.cc
index dc01a6e47c4..4baf30238a4 100644
--- a/gcc/config/c6x/c6x.cc
+++ b/gcc/config/c6x/c6x.cc
@@ -195,7 +195,7 @@ typedef int unit_req_table[2][UNIT_REQ_MAX];
 static unit_req_table unit_reqs;
 
 /* Register map for debugging.  */
-unsigned const dbx_register_map[FIRST_PSEUDO_REGISTER] =
+unsigned const debugger_register_map[FIRST_PSEUDO_REGISTER] =
 {
   0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,	/* A0 - A15.  */
   37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49,	/* A16 - A32.  */
diff --git a/gcc/config/c6x/c6x.h b/gcc/config/c6x/c6x.h
index 766ce1e38e1..82ccd5161a5 100644
--- a/gcc/config/c6x/c6x.h
+++ b/gcc/config/c6x/c6x.h
@@ -503,9 +503,9 @@ struct GTY(()) machine_function
     "B24", "B25", "B26", "B27", "B28", "B29", "B30", "B31",	\
     "FP", "ARGP", "ILC" }
 
-#define DBX_REGISTER_NUMBER(N) (dbx_register_map[(N)])
+#define DEBUGGER_REGISTER_NUMBER(N) (debugger_register_map[(N)])
 
-extern unsigned const dbx_register_map[FIRST_PSEUDO_REGISTER];
+extern unsigned const debugger_register_map[FIRST_PSEUDO_REGISTER];
 
 #define FINAL_PRESCAN_INSN c6x_final_prescan_insn
 
diff --git a/gcc/config/cris/cris.h b/gcc/config/cris/cris.h
index 6edfe13d92c..d29aa368a5f 100644
--- a/gcc/config/cris/cris.h
+++ b/gcc/config/cris/cris.h
@@ -570,7 +570,7 @@ enum reg_class
    an inverse mapping from dwarf register to gcc register.  There is one
    need in dwarf2out.cc:expand_builtin_init_dwarf_reg_sizes.  Right now, I
    don't see that we need exact correspondence between DWARF *frame*
-   registers and DBX_REGISTER_NUMBER, so map them onto GCC registers.  */
+   registers and DEBUGGER_REGISTER_NUMBER, so map them onto GCC registers.  */
 #define DWARF_FRAME_REGNUM(REG) (REG)
 
 /* Node: Stack Checking */
@@ -888,7 +888,7 @@ struct cum_args {int regs;};
 
 /* Node: All Debuggers */
 
-#define DBX_REGISTER_NUMBER(REGNO)				\
+#define DEBUGGER_REGISTER_NUMBER(REGNO)				\
  ((REGNO) == CRIS_SRP_REGNUM ? CRIS_CANONICAL_SRP_REGNUM :	\
   (REGNO) == CRIS_MOF_REGNUM ? CRIS_CANONICAL_MOF_REGNUM :	\
   (REGNO) == CRIS_CC0_REGNUM ? CRIS_CANONICAL_CC0_REGNUM :	\
diff --git a/gcc/config/csky/csky.cc b/gcc/config/csky/csky.cc
index e315e09a8fe..a7dc6cefead 100644
--- a/gcc/config/csky/csky.cc
+++ b/gcc/config/csky/csky.cc
@@ -172,7 +172,7 @@ enum reg_class regno_reg_class[FIRST_PSEUDO_REGISTER] =
 /* Arrays that map GCC register numbers to debugger register numbers,
    '-1' means that is INVALID_REGNUM.
    TODO: which rules according to here ?  */
-const int csky_dbx_regno[FIRST_PSEUDO_REGISTER] =
+const int csky_debugger_regno[FIRST_PSEUDO_REGISTER] =
 {
   0,  1,  2,  3,  4,  5,  6,  7,
   8,  9,  10, 11, 12, 13, 14, 15,
diff --git a/gcc/config/csky/csky.h b/gcc/config/csky/csky.h
index 22b1151b7ea..fa46a330d14 100644
--- a/gcc/config/csky/csky.h
+++ b/gcc/config/csky/csky.h
@@ -997,7 +997,7 @@ while (0)
    is different from that used in other debug info sections.
    Given a GCC hard register number,
    this macro should return the .eh_frame register number.*/
-#define DWARF_FRAME_REGNUM(REG)	 DBX_REGISTER_NUMBER (REG)
+#define DWARF_FRAME_REGNUM(REG)	 DEBUGGER_REGISTER_NUMBER (REG)
 
 /* If INCOMING_RETURN_ADDR_RTX is defined & the RTL is REG,
    define DWARF_FRAME_RETURN_COLUMN to DWARF_FRAME_REGNUM.  */
@@ -1006,9 +1006,9 @@ while (0)
 /* Use r0 and r1 to pass exception handling information.  */
 #define EH_RETURN_DATA_REGNO(N) ((N) < 2 ? N : INVALID_REGNUM)
 
-/* How to renumber registers for dbx and gdb.  */
-extern const int csky_dbx_regno[];
-#define DBX_REGISTER_NUMBER(REGNO) ((unsigned int) csky_dbx_regno[REGNO])
+/* How to renumber registers for gdb.  */
+extern const int csky_debugger_regno[];
+#define DEBUGGER_REGISTER_NUMBER(REGNO) ((unsigned int) csky_debugger_regno[REGNO])
 
 
 /******************************************************************
diff --git a/gcc/config/gcn/gcn-hsa.h b/gcc/config/gcn/gcn-hsa.h
index b3079cebb43..25a8c45b200 100644
--- a/gcc/config/gcn/gcn-hsa.h
+++ b/gcc/config/gcn/gcn-hsa.h
@@ -113,4 +113,4 @@ extern const char *last_arg_spec_function (int argc, const char **argv);
 #define DWARF2_DEBUGGING_INFO      1
 #define DWARF2_ASM_LINE_DEBUG_INFO 1
 #define EH_FRAME_THROUGH_COLLECT2  1
-#define DBX_REGISTER_NUMBER(REGNO) gcn_dwarf_register_number (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) gcn_dwarf_register_number (REGNO)
diff --git a/gcc/config/gcn/gcn.cc b/gcc/config/gcn/gcn.cc
index ceb69000807..063073ce552 100644
--- a/gcc/config/gcn/gcn.cc
+++ b/gcc/config/gcn/gcn.cc
@@ -6510,7 +6510,7 @@ print_operand (FILE *file, rtx x, int code)
   gcc_unreachable ();
 }
 
-/* Implement DBX_REGISTER_NUMBER macro.
+/* Implement DEBUGGER_REGISTER_NUMBER macro.
  
    Return the DWARF register number that corresponds to the GCC internal
    REGNO.  */
diff --git a/gcc/config/i386/bsd.h b/gcc/config/i386/bsd.h
index 98d2810e975..817fb6edf91 100644
--- a/gcc/config/i386/bsd.h
+++ b/gcc/config/i386/bsd.h
@@ -36,7 +36,7 @@ along with GCC; see the file COPYING3.  If not see
 #define ASM_LONG "\t.long\t"
 #define ASM_QUAD "\t.quad\t"  /* Should not be used for 32bit compilation.  */
 
-/* This was suggested, but it shouldn't be right for DBX output. -- RMS
+/* This was suggested, but it shouldn't be right for debugger output. -- RMS
    #define ASM_OUTPUT_SOURCE_FILENAME(FILE, NAME) */
 
 
diff --git a/gcc/config/i386/cygming.h b/gcc/config/i386/cygming.h
index 45150458cc5..db54cc511c0 100644
--- a/gcc/config/i386/cygming.h
+++ b/gcc/config/i386/cygming.h
@@ -72,19 +72,19 @@ along with GCC; see the file COPYING3.  If not see
 
 #endif
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n)				\
-  (TARGET_64BIT ? dbx64_register_map[n]			\
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n)				\
+  (TARGET_64BIT ? debugger64_register_map[n]			\
    : (dwarf_debuginfo_p ()				\
-      ? svr4_dbx_register_map[n] : dbx_register_map[n]))
+      ? svr4_debugger_register_map[n] : debugger_register_map[n]))
 
 /* Map gcc register number to DWARF 2 CFA column number. For 32 bit
-   target, always use the svr4_dbx_register_map for DWARF .eh_frame
+   target, always use the svr4_debugger_register_map for DWARF .eh_frame
    even if we don't use DWARF .debug_frame. */
 #undef DWARF_FRAME_REGNUM
 #define DWARF_FRAME_REGNUM(n)				\
-  (TARGET_64BIT ? dbx64_register_map[(n)]		\
-		: svr4_dbx_register_map[(n)])
+  (TARGET_64BIT ? debugger64_register_map[(n)]		\
+		: svr4_debugger_register_map[(n)])
 
 /* The 64-bit MS_ABI changes the set of call-used registers.  */
 #undef DWARF_FRAME_REGISTERS
diff --git a/gcc/config/i386/darwin.h b/gcc/config/i386/darwin.h
index a55f6b2b874..75657025f25 100644
--- a/gcc/config/i386/darwin.h
+++ b/gcc/config/i386/darwin.h
@@ -237,11 +237,11 @@ along with GCC; see the file COPYING3.  If not see
 /* Darwin uses the standard DWARF register numbers but the default
    register numbers for STABS.  Fortunately for 64-bit code the
    default and the standard are the same.  */
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) 					\
-  (TARGET_64BIT ? dbx64_register_map[n]				\
-   : dwarf_debuginfo_p () ? svr4_dbx_register_map[n]		\
-   : dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) 					\
+  (TARGET_64BIT ? debugger64_register_map[n]				\
+   : dwarf_debuginfo_p () ? svr4_debugger_register_map[n]		\
+   : debugger_register_map[n])
 
 /* Unfortunately, the 32-bit EH information also doesn't use the standard
    DWARF register numbers.  */
diff --git a/gcc/config/i386/djgpp.h b/gcc/config/i386/djgpp.h
index 909821e953b..b01302e9e69 100644
--- a/gcc/config/i386/djgpp.h
+++ b/gcc/config/i386/djgpp.h
@@ -128,8 +128,8 @@ along with GCC; see the file COPYING3.  If not see
 #undef PTRDIFF_TYPE
 #define PTRDIFF_TYPE "int"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) svr4_dbx_register_map[n]
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) svr4_debugger_register_map[n]
 
 /* Default to pcc-struct-return.  */
 #define DEFAULT_PCC_STRUCT_RETURN 1
diff --git a/gcc/config/i386/dragonfly.h b/gcc/config/i386/dragonfly.h
index 39bd280d2b8..3c002744575 100644
--- a/gcc/config/i386/dragonfly.h
+++ b/gcc/config/i386/dragonfly.h
@@ -34,9 +34,9 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 #undef  ASM_APP_OFF
 #define ASM_APP_OFF "#NO_APP\n"
 
-#undef  DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef  DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 #undef  NO_PROFILE_COUNTERS
 #define NO_PROFILE_COUNTERS	1
diff --git a/gcc/config/i386/freebsd.h b/gcc/config/i386/freebsd.h
index 120e24c81f3..550b4b7b1cc 100644
--- a/gcc/config/i386/freebsd.h
+++ b/gcc/config/i386/freebsd.h
@@ -32,9 +32,9 @@ along with GCC; see the file COPYING3.  If not see
 #undef  ASM_APP_OFF
 #define ASM_APP_OFF "#NO_APP\n"
 
-#undef  DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef  DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 #undef  NO_PROFILE_COUNTERS
 #define NO_PROFILE_COUNTERS	1
diff --git a/gcc/config/i386/gas.h b/gcc/config/i386/gas.h
index e0ffc75dc6d..317bc868b0a 100644
--- a/gcc/config/i386/gas.h
+++ b/gcc/config/i386/gas.h
@@ -31,7 +31,7 @@ along with GCC; see the file COPYING3.  If not see
  * Next is the question of whether to uses underscores.  RMS didn't
  * like this idea at first, but since it is now obvious that we
  * need this separate tm file for use with gas, at least to get
- * dbx debugging info, I think we should also switch to underscores.
+ * debugging info, I think we should also switch to underscores.
  * We can keep i386v for real att style output, and the few
  * people who want both form will have to compile twice.
  */
diff --git a/gcc/config/i386/gnu-user.h b/gcc/config/i386/gnu-user.h
index 0102b2a6f3b..d476e48c5f1 100644
--- a/gcc/config/i386/gnu-user.h
+++ b/gcc/config/i386/gnu-user.h
@@ -26,9 +26,9 @@ along with GCC; see the file COPYING3.  If not see
 #undef ASM_COMMENT_START
 #define ASM_COMMENT_START "#"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 /* Output assembler code to FILE to call the profiler.
    To the best of my knowledge, no GNU userspace libc has required the label
diff --git a/gcc/config/i386/i386.cc b/gcc/config/i386/i386.cc
index c4d0e36e9c0..dadf453d6c0 100644
--- a/gcc/config/i386/i386.cc
+++ b/gcc/config/i386/i386.cc
@@ -173,7 +173,7 @@ enum reg_class const regclass_map[FIRST_PSEUDO_REGISTER] =
 
 /* The "default" register map used in 32bit mode.  */
 
-int const dbx_register_map[FIRST_PSEUDO_REGISTER] =
+int const debugger_register_map[FIRST_PSEUDO_REGISTER] =
 {
   /* general regs */
   0, 2, 1, 3, 6, 7, 4, 5,
@@ -204,7 +204,7 @@ int const dbx_register_map[FIRST_PSEUDO_REGISTER] =
 
 /* The "default" register map used in 64bit mode.  */
 
-int const dbx64_register_map[FIRST_PSEUDO_REGISTER] =
+int const debugger64_register_map[FIRST_PSEUDO_REGISTER] =
 {
   /* general regs */
   0, 1, 2, 3, 4, 5, 6, 7,
@@ -283,7 +283,7 @@ int const dbx64_register_map[FIRST_PSEUDO_REGISTER] =
 	17 for %st(6) (gcc regno = 14)
 	18 for %st(7) (gcc regno = 15)
 */
-int const svr4_dbx_register_map[FIRST_PSEUDO_REGISTER] =
+int const svr4_debugger_register_map[FIRST_PSEUDO_REGISTER] =
 {
   /* general regs */
   0, 2, 1, 3, 6, 7, 5, 4,
diff --git a/gcc/config/i386/i386.h b/gcc/config/i386/i386.h
index 0de5c77bc7d..5d7bac8c5df 100644
--- a/gcc/config/i386/i386.h
+++ b/gcc/config/i386/i386.h
@@ -2035,14 +2035,14 @@ do {							\
   { "zmm28", XMM28_REG }, { "zmm29", XMM29_REG }, { "zmm30", XMM30_REG }, { "zmm31", XMM31_REG }  \
 }
 
-/* How to renumber registers for dbx and gdb.  */
+/* How to renumber registers for gdb.  */
 
-#define DBX_REGISTER_NUMBER(N) \
-  (TARGET_64BIT ? dbx64_register_map[(N)] : dbx_register_map[(N)])
+#define DEBUGGER_REGISTER_NUMBER(N) \
+  (TARGET_64BIT ? debugger64_register_map[(N)] : debugger_register_map[(N)])
 
-extern int const dbx_register_map[FIRST_PSEUDO_REGISTER];
-extern int const dbx64_register_map[FIRST_PSEUDO_REGISTER];
-extern int const svr4_dbx_register_map[FIRST_PSEUDO_REGISTER];
+extern int const debugger_register_map[FIRST_PSEUDO_REGISTER];
+extern int const debugger64_register_map[FIRST_PSEUDO_REGISTER];
+extern int const svr4_debugger_register_map[FIRST_PSEUDO_REGISTER];
 
 /* Before the prologue, RA is at 0(%esp).  */
 #define INCOMING_RETURN_ADDR_RTX \
diff --git a/gcc/config/i386/i386elf.h b/gcc/config/i386/i386elf.h
index 50f7067532d..894469e162b 100644
--- a/gcc/config/i386/i386elf.h
+++ b/gcc/config/i386/i386elf.h
@@ -36,9 +36,9 @@ along with GCC; see the file COPYING3.  If not see
 			  %{pg:gcrt0.o%s}%{!pg:%{p:mcrt0.o%s}%{!p:crt0.o%s}}}}\
 			crtbegin.o%s"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 #define LOCAL_LABEL_PREFIX	"."
 
diff --git a/gcc/config/i386/iamcu.h b/gcc/config/i386/iamcu.h
index ff94cc5b399..99a6b9ade3e 100644
--- a/gcc/config/i386/iamcu.h
+++ b/gcc/config/i386/iamcu.h
@@ -33,9 +33,9 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 #undef ASM_COMMENT_START
 #define ASM_COMMENT_START "#"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 #undef ASM_SPEC
 #define ASM_SPEC "--32 -march=iamcu"
diff --git a/gcc/config/i386/lynx.h b/gcc/config/i386/lynx.h
index baa62c14986..986fa6ab1fb 100644
--- a/gcc/config/i386/lynx.h
+++ b/gcc/config/i386/lynx.h
@@ -37,9 +37,9 @@ along with GCC; see the file COPYING3.  If not see
 
 /* LynxOS's GDB counts the floating point registers from 16.  */
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n)						\
-  (TARGET_64BIT ? dbx64_register_map[n]					\
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n)						\
+  (TARGET_64BIT ? debugger64_register_map[n]					\
    : (n) == 0 ? 0							\
    : (n) == 1 ? 2							\
    : (n) == 2 ? 1							\
diff --git a/gcc/config/i386/netbsd-elf.h b/gcc/config/i386/netbsd-elf.h
index b1d7d484ce7..7842035fbef 100644
--- a/gcc/config/i386/netbsd-elf.h
+++ b/gcc/config/i386/netbsd-elf.h
@@ -66,8 +66,8 @@ along with GCC; see the file COPYING3.  If not see
 #undef ASM_COMMENT_START
 #define ASM_COMMENT_START "#"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n)  svr4_dbx_register_map[n]
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n)  svr4_debugger_register_map[n]
 
 
 /* Output assembler code to FILE to call the profiler.  */
diff --git a/gcc/config/i386/nto.h b/gcc/config/i386/nto.h
index 5df300918d9..16d9808fa35 100644
--- a/gcc/config/i386/nto.h
+++ b/gcc/config/i386/nto.h
@@ -100,4 +100,4 @@ crti.o%s \
 
 #define TARGET_POSIX_IO
 
-#undef DBX_REGISTER_NUMBER
+#undef DEBUGGER_REGISTER_NUMBER
diff --git a/gcc/config/i386/openbsdelf.h b/gcc/config/i386/openbsdelf.h
index 2176e79495c..88f2bc8fd83 100644
--- a/gcc/config/i386/openbsdelf.h
+++ b/gcc/config/i386/openbsdelf.h
@@ -25,9 +25,9 @@ along with GCC; see the file COPYING3.  If not see
     }						\
   while (0)
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 /* This must agree with <machine/_types.h>.  */
 #undef SIZE_TYPE
diff --git a/gcc/config/i386/sysv4.h b/gcc/config/i386/sysv4.h
index b7db9571a68..0bb8b1d90c6 100644
--- a/gcc/config/i386/sysv4.h
+++ b/gcc/config/i386/sysv4.h
@@ -26,8 +26,8 @@ along with GCC; see the file COPYING3.  If not see
 #undef X86_FILE_START_VERSION_DIRECTIVE
 #define X86_FILE_START_VERSION_DIRECTIVE true
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n)  svr4_dbx_register_map[n]
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n)  svr4_debugger_register_map[n]
 
 /* A C statement (sans semicolon) to output to the stdio stream
    FILE the assembler definition of uninitialized global DECL named
diff --git a/gcc/config/i386/x86-64.h b/gcc/config/i386/x86-64.h
index 065269908e1..3d6f8be6a1e 100644
--- a/gcc/config/i386/x86-64.h
+++ b/gcc/config/i386/x86-64.h
@@ -26,9 +26,9 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 #undef ASM_COMMENT_START
 #define ASM_COMMENT_START "#"
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 /* Output assembler code to FILE to call the profiler.  */
 #define NO_PROFILE_COUNTERS 1
diff --git a/gcc/config/ia64/ia64-protos.h b/gcc/config/ia64/ia64-protos.h
index 77e0cf7c72b..26ffd77c59d 100644
--- a/gcc/config/ia64/ia64-protos.h
+++ b/gcc/config/ia64/ia64-protos.h
@@ -83,7 +83,7 @@ extern int ia64_epilogue_uses (int);
 extern int ia64_eh_uses (int);
 extern void emit_safe_across_calls (void);
 extern void ia64_init_builtins (void);
-extern int ia64_dbx_register_number (int);
+extern int ia64_debugger_register_number (int);
 
 extern rtx ia64_return_addr_rtx (HOST_WIDE_INT, rtx);
 extern void ia64_split_return_addr_rtx (rtx);
diff --git a/gcc/config/ia64/ia64.cc b/gcc/config/ia64/ia64.cc
index 25e4a47e363..42508af9685 100644
--- a/gcc/config/ia64/ia64.cc
+++ b/gcc/config/ia64/ia64.cc
@@ -4421,7 +4421,7 @@ ia64_output_function_prologue (FILE *file)
 
   if (mask && TARGET_GNU_AS)
     fprintf (file, "\t.prologue %d, %d\n", mask,
-	     ia64_dbx_register_number (grsave));
+	     ia64_debugger_register_number (grsave));
   else
     fputs ("\t.prologue\n", file);
 
@@ -4473,7 +4473,7 @@ ia64_output_function_epilogue (FILE *)
 }
 
 int
-ia64_dbx_register_number (int regno)
+ia64_debugger_register_number (int regno)
 {
   /* In ia64_expand_prologue we quite literally renamed the frame pointer
      from its home at loc79 to something inside the register frame.  We
@@ -10104,7 +10104,7 @@ process_cfa_adjust_cfa (FILE *out_file, rtx pat, rtx insn,
 
       if (unwind)
 	fprintf (out_file, "\t.vframe r%d\n",
-		 ia64_dbx_register_number (REGNO (dest)));
+		 ia64_debugger_register_number (REGNO (dest)));
     }
   else
     gcc_unreachable ();
@@ -10125,7 +10125,7 @@ process_cfa_register (FILE *out_file, rtx pat, bool unwind)
       /* Saving return address pointer.  */
       if (unwind)
 	fprintf (out_file, "\t.save rp, r%d\n",
-		 ia64_dbx_register_number (dest_regno));
+		 ia64_debugger_register_number (dest_regno));
       return;
     }
 
@@ -10137,21 +10137,21 @@ process_cfa_register (FILE *out_file, rtx pat, bool unwind)
       gcc_assert (dest_regno == current_frame_info.r[reg_save_pr]);
       if (unwind)
 	fprintf (out_file, "\t.save pr, r%d\n",
-		 ia64_dbx_register_number (dest_regno));
+		 ia64_debugger_register_number (dest_regno));
       break;
 
     case AR_UNAT_REGNUM:
       gcc_assert (dest_regno == current_frame_info.r[reg_save_ar_unat]);
       if (unwind)
 	fprintf (out_file, "\t.save ar.unat, r%d\n",
-		 ia64_dbx_register_number (dest_regno));
+		 ia64_debugger_register_number (dest_regno));
       break;
 
     case AR_LC_REGNUM:
       gcc_assert (dest_regno == current_frame_info.r[reg_save_ar_lc]);
       if (unwind)
 	fprintf (out_file, "\t.save ar.lc, r%d\n",
-		 ia64_dbx_register_number (dest_regno));
+		 ia64_debugger_register_number (dest_regno));
       break;
 
     default:
@@ -10326,7 +10326,7 @@ ia64_asm_unwind_emit (FILE *out_file, rtx_insn *insn)
 	{
 	  if (unwind)
 	    fprintf (out_file, "\t.save ar.pfs, r%d\n",
-		     ia64_dbx_register_number (dest_regno));
+		     ia64_debugger_register_number (dest_regno));
 	}
       else
 	{
diff --git a/gcc/config/ia64/ia64.h b/gcc/config/ia64/ia64.h
index 69646625eae..b7415c53596 100644
--- a/gcc/config/ia64/ia64.h
+++ b/gcc/config/ia64/ia64.h
@@ -1422,20 +1422,6 @@ do {									\
 /* Macros Affecting all Debug Formats.  */
 
 /* This is handled in sysv4.h.  */
-
-
-/* Specific Options for DBX Output.  */
-
-
-/* Open ended Hooks for DBX Output.  */
-
-/* Likewise.  */
-
-
-/* File names in DBX format.  */
-
-/* Likewise.  */
-
 
 /* Macros for Dwarf Output.  */
 
diff --git a/gcc/config/ia64/sysv4.h b/gcc/config/ia64/sysv4.h
index 046c5110195..4b13a792659 100644
--- a/gcc/config/ia64/sysv4.h
+++ b/gcc/config/ia64/sysv4.h
@@ -100,8 +100,8 @@ do {						\
 #undef FINI_SECTION_ASM_OP
 #define FINI_SECTION_ASM_OP	"\t.section\t.fini,\"ax\",\"progbits\""
 
-#define DBX_REGISTER_NUMBER(REGNO) \
-  ia64_dbx_register_number(REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
+  ia64_debugger_register_number(REGNO)
 
 #undef SIZE_TYPE
 #define SIZE_TYPE "long unsigned int"
diff --git a/gcc/config/lm32/lm32.h b/gcc/config/lm32/lm32.h
index 23f66c90446..39eb20fe77b 100644
--- a/gcc/config/lm32/lm32.h
+++ b/gcc/config/lm32/lm32.h
@@ -491,7 +491,7 @@ do {                                                            \
 /* Debugging.  */
 /*-------------*/
 
-#define DBX_REGISTER_NUMBER(REGNO) (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) (REGNO)
 
 #define DEFAULT_GDB_EXTENSIONS 1
 
diff --git a/gcc/config/m32c/m32c.cc b/gcc/config/m32c/m32c.cc
index 5a19faa063c..11e7554363f 100644
--- a/gcc/config/m32c/m32c.cc
+++ b/gcc/config/m32c/m32c.cc
@@ -1013,7 +1013,7 @@ m32c_eh_return_stackadj_rtx (void)
 
 /* Registers That Address the Stack Frame */
 
-/* Implements DWARF_FRAME_REGNUM and DBX_REGISTER_NUMBER.  Note that
+/* Implements DWARF_FRAME_REGNUM and DEBUGGER_REGISTER_NUMBER.  Note that
    the original spec called for dwarf numbers to vary with register
    width as well, for example, r0l, r0, and r2r0 would each have
    different dwarf numbers.  GCC doesn't support this, and we don't do
diff --git a/gcc/config/m32c/m32c.h b/gcc/config/m32c/m32c.h
index af99103fd64..9a706345363 100644
--- a/gcc/config/m32c/m32c.h
+++ b/gcc/config/m32c/m32c.h
@@ -452,7 +452,7 @@ enum reg_class
 
 #define DWARF_FRAME_REGISTERS 20
 #define DWARF_FRAME_REGNUM(N) m32c_dwarf_frame_regnum (N)
-#define DBX_REGISTER_NUMBER(N) m32c_dwarf_frame_regnum (N)
+#define DEBUGGER_REGISTER_NUMBER(N) m32c_dwarf_frame_regnum (N)
 
 #undef ASM_PREFERRED_EH_DATA_FORMAT
 /* This is the same as the default in practice, except that by making
diff --git a/gcc/config/m68k/linux.h b/gcc/config/m68k/linux.h
index 0c66c91f840..72a127bce9a 100644
--- a/gcc/config/m68k/linux.h
+++ b/gcc/config/m68k/linux.h
@@ -224,8 +224,8 @@ along with GCC; see the file COPYING3.  If not see
 
 #define TARGET_ASM_FILE_END file_end_indicate_exec_stack
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(REGNO) (REGNO)
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(REGNO) (REGNO)
 
 #undef  SIZE_TYPE
 #define SIZE_TYPE "unsigned int"
diff --git a/gcc/config/m68k/m68k.h b/gcc/config/m68k/m68k.h
index cd353db41a6..6f93442ad97 100644
--- a/gcc/config/m68k/m68k.h
+++ b/gcc/config/m68k/m68k.h
@@ -707,7 +707,7 @@ __transfer_from_trampoline ()					\
 
 /* On the Sun-3, the floating point registers have numbers
    18 to 25, not 16 to 23 as they do in the compiler.  */
-#define DBX_REGISTER_NUMBER(REGNO) ((REGNO) < 16 ? (REGNO) : (REGNO) + 2)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) ((REGNO) < 16 ? (REGNO) : (REGNO) + 2)
 
 /* Before the prologue, RA is at 0(%sp).  */
 #define INCOMING_RETURN_ADDR_RTX \
@@ -720,7 +720,7 @@ __transfer_from_trampoline ()					\
 					UNITS_PER_WORD))		   \
    : gen_rtx_MEM (Pmode, plus_constant (Pmode, FRAME, UNITS_PER_WORD)))
 
-/* We must not use the DBX register numbers for the DWARF 2 CFA column
+/* We must not use the debugger register numbers for the DWARF 2 CFA column
    numbers because that maps to numbers beyond FIRST_PSEUDO_REGISTER.
    Instead use the identity mapping.  */
 #define DWARF_FRAME_REGNUM(REG) \
diff --git a/gcc/config/m68k/m68kelf.h b/gcc/config/m68k/m68kelf.h
index 8133e64e563..09574fc00e7 100644
--- a/gcc/config/m68k/m68kelf.h
+++ b/gcc/config/m68k/m68kelf.h
@@ -100,8 +100,8 @@ do {								\
    SVR4 debugger in the m68k/SVR4 reference port, where d0-d7
    are 0-7, a0-a8 are 8-15, and fp0-fp7 are 16-23.  */
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(REGNO) (REGNO)
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(REGNO) (REGNO)
 
 #if 0
 /* SVR4 m68k assembler is bitching on the `comm i,1,1' which askes for 
diff --git a/gcc/config/m68k/netbsd-elf.h b/gcc/config/m68k/netbsd-elf.h
index d262b60bbf2..52415a772b7 100644
--- a/gcc/config/m68k/netbsd-elf.h
+++ b/gcc/config/m68k/netbsd-elf.h
@@ -215,13 +215,13 @@ while (0)
 #define M68K_STATIC_CHAIN_REG_NAME REGISTER_PREFIX "a1"
 
 
-/* Now to renumber registers for dbx and gdb.
+/* Now to renumber registers for gdb.
    We use the Sun-3 convention, which is:
    floating point registers have numbers 18 to 25, not
    16 to 23 as they do in the compiler.  */
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(REGNO) ((REGNO) < 16 ? (REGNO) : (REGNO) + 2)
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(REGNO) ((REGNO) < 16 ? (REGNO) : (REGNO) + 2)
 
 
 /* 1 if N is a possible register number for a function value.  For
diff --git a/gcc/config/microblaze/microblaze.cc b/gcc/config/microblaze/microblaze.cc
index f32effecfb6..8fcca1829f6 100644
--- a/gcc/config/microblaze/microblaze.cc
+++ b/gcc/config/microblaze/microblaze.cc
@@ -193,7 +193,7 @@ struct microblaze_frame_info zero_frame_info;
 char microblaze_print_operand_punct[256];
 
 /* Map GCC register number to debugger register number.  */
-int microblaze_dbx_regno[FIRST_PSEUDO_REGISTER];
+int microblaze_debugger_regno[FIRST_PSEUDO_REGISTER];
 
 /* Map hard register number to register class.  */
 enum reg_class microblaze_regno_to_class[] =
@@ -1881,11 +1881,11 @@ microblaze_option_override (void)
      Ignore the special purpose register numbers.  */
 
   for (i = 0; i < FIRST_PSEUDO_REGISTER; i++)
-    microblaze_dbx_regno[i] = -1;
+    microblaze_debugger_regno[i] = -1;
 
-  start = GP_DBX_FIRST - GP_REG_FIRST;
+  start = GP_DEBUGGER_FIRST - GP_REG_FIRST;
   for (i = GP_REG_FIRST; i <= GP_REG_LAST; i++)
-    microblaze_dbx_regno[i] = i + start;
+    microblaze_debugger_regno[i] = i + start;
 
   /* Set up array giving whether a given register can hold a given mode.   */
 
diff --git a/gcc/config/microblaze/microblaze.h b/gcc/config/microblaze/microblaze.h
index d28bc766de8..97e9be0e119 100644
--- a/gcc/config/microblaze/microblaze.h
+++ b/gcc/config/microblaze/microblaze.h
@@ -39,7 +39,7 @@ extern char microblaze_print_operand_punct[];
 extern int microblaze_section_threshold;
 
 /* Map register # to debug register # */
-extern int microblaze_dbx_regno[];
+extern int microblaze_debugger_regno[];
 
 extern int microblaze_no_unsafe_delay;
 extern int microblaze_has_clz;
@@ -163,8 +163,8 @@ extern enum pipeline_type microblaze_pipe;
 
 /* Debug stuff.  */
 
-/* How to renumber registers for dbx and gdb.  */
-#define DBX_REGISTER_NUMBER(REGNO) microblaze_dbx_regno[(REGNO)]
+/* How to renumber registers for gdb.  */
+#define DEBUGGER_REGISTER_NUMBER(REGNO) microblaze_debugger_regno[(REGNO)]
 
 /* Generate DWARF exception handling info.  */
 #define DWARF2_UNWIND_INFO 1
@@ -276,7 +276,7 @@ extern enum pipeline_type microblaze_pipe;
 #define GP_REG_FIRST    0
 #define GP_REG_LAST     31
 #define GP_REG_NUM      (GP_REG_LAST - GP_REG_FIRST + 1)
-#define GP_DBX_FIRST    0
+#define GP_DEBUGGER_FIRST    0
 
 #define ST_REG		32
 #define AP_REG_NUM      33
diff --git a/gcc/config/mips/vxworks.h b/gcc/config/mips/vxworks.h
index 11a71e09fa9..f4da241ed47 100644
--- a/gcc/config/mips/vxworks.h
+++ b/gcc/config/mips/vxworks.h
@@ -75,4 +75,4 @@ VXWORKS_LINK_SPEC
 #undef SUBTARGET_OVERRIDE_OPTIONS
 #define SUBTARGET_OVERRIDE_OPTIONS VXWORKS_OVERRIDE_OPTIONS
 
-#undef DBX_REGISTER_NUMBER
+#undef DEBUGGER_REGISTER_NUMBER
diff --git a/gcc/config/mmix/mmix-protos.h b/gcc/config/mmix/mmix-protos.h
index d9a40d3b941..8055081664e 100644
--- a/gcc/config/mmix/mmix-protos.h
+++ b/gcc/config/mmix/mmix-protos.h
@@ -42,7 +42,7 @@ extern int mmix_shiftable_wyde_value (uint64_t);
 extern void mmix_output_register_setting (FILE *, int, int64_t, int);
 extern int mmix_opposite_regno (int, int);
 extern int mmix_local_regno (int);
-extern unsigned mmix_dbx_register_number (unsigned);
+extern unsigned mmix_debugger_register_number (unsigned);
 extern int mmix_use_simple_return (void);
 extern void mmix_make_decl_one_only (tree);
 extern int mmix_data_alignment (tree, int);
diff --git a/gcc/config/mmix/mmix.cc b/gcc/config/mmix/mmix.cc
index 439ae8f044f..90bd713caa4 100644
--- a/gcc/config/mmix/mmix.cc
+++ b/gcc/config/mmix/mmix.cc
@@ -1942,10 +1942,10 @@ mmix_asm_output_align (FILE *stream, int power)
  fprintf (stream, "\tLOC @+(%d-@)&%d\n", 1 << power, (1 << power) - 1);
 }
 
-/* DBX_REGISTER_NUMBER.  */
+/* DEBUGGER_REGISTER_NUMBER.  */
 
 unsigned
-mmix_dbx_register_number (unsigned regno)
+mmix_debugger_register_number (unsigned regno)
 {
   /* Adjust the register number to the one it will be output as, dammit.
      It'd be nice if we could check the assumption that we're filling a
@@ -1956,7 +1956,7 @@ mmix_dbx_register_number (unsigned regno)
   /* We need to renumber registers to get the number of the return address
      register in the range 0..255.  It is also space-saving if registers
      mentioned in the call-frame information (which uses this function by
-     defaulting DWARF_FRAME_REGNUM to DBX_REGISTER_NUMBER) are numbered
+     defaulting DWARF_FRAME_REGNUM to DEBUGGER_REGISTER_NUMBER) are numbered
      0 .. 63.  So map 224 .. 256+15 -> 0 .. 47 and 0 .. 223 -> 48..223+48.  */
   return regno >= 224 ? (regno - 224) : (regno + 48);
 }
diff --git a/gcc/config/mmix/mmix.h b/gcc/config/mmix/mmix.h
index 0fc45db6d74..42cc01c1a6e 100644
--- a/gcc/config/mmix/mmix.h
+++ b/gcc/config/mmix/mmix.h
@@ -757,17 +757,8 @@ typedef struct { int regs; int lib; } CUMULATIVE_ARGS;
 
 /* Node: All Debuggers */
 
-#define DBX_REGISTER_NUMBER(REGNO) \
- mmix_dbx_register_number (REGNO)
-
-
-/* Node: DBX Options */
-/* (empty) */
-/* Node: DBX Hooks */
-/* (empty) */
-/* Node: File Names and DBX */
-/* (empty) */
-
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
+ mmix_debugger_register_number (REGNO)
 
 /* Node: DWARF */
 #define DWARF2_DEBUGGING_INFO 1
diff --git a/gcc/config/nds32/nds32-protos.h b/gcc/config/nds32/nds32-protos.h
index 377423c7937..8b097395bbc 100644
--- a/gcc/config/nds32/nds32-protos.h
+++ b/gcc/config/nds32/nds32-protos.h
@@ -65,7 +65,7 @@ extern void nds32_emit_v3pop_fpr_callee_saved (int);
 
 /* Controlling Debugging Information Format.  */
 
-extern unsigned int nds32_dbx_register_number (unsigned int);
+extern unsigned int nds32_debugger_register_number (unsigned int);
 
 /* ------------------------------------------------------------------------ */
 
diff --git a/gcc/config/nds32/nds32.cc b/gcc/config/nds32/nds32.cc
index 71fe9e8bcd6..af8aa4eaa6f 100644
--- a/gcc/config/nds32/nds32.cc
+++ b/gcc/config/nds32/nds32.cc
@@ -3889,7 +3889,7 @@ nds32_dwarf_register_span (rtx reg)
 /* Map internal gcc register numbers to DWARF2 register numbers.  */
 
 unsigned int
-nds32_dbx_register_number (unsigned int regno)
+nds32_debugger_register_number (unsigned int regno)
 {
   /* The nds32 port in GDB maintains a mapping between dwarf register
      number and displayed register name.  For backward compatibility to
@@ -5809,12 +5809,6 @@ nds32_use_blocks_for_constant_p (machine_mode mode,
 
 /* -- Macros Affecting All Debugging Formats.  */
 
-/* -- Specific Options for DBX Output.  */
-
-/* -- Open-Ended Hooks for DBX Format.  */
-
-/* -- File Names in DBX Format.  */
-
 /* -- Macros for DWARF Output.  */
 
 /* -- Macros for VMS Debug Format.  */
diff --git a/gcc/config/nds32/nds32.h b/gcc/config/nds32/nds32.h
index 18ef8ae9ee8..45e4bbab999 100644
--- a/gcc/config/nds32/nds32.h
+++ b/gcc/config/nds32/nds32.h
@@ -1332,7 +1332,7 @@ enum reg_class
    This is used to unwind the stack to an exception handler's call frame.  */
 #define EH_RETURN_STACKADJ_RTX gen_rtx_REG (Pmode, 2)
 
-#define DBX_REGISTER_NUMBER(REGNO) nds32_dbx_register_number (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) nds32_debugger_register_number (REGNO)
 
 #define STACK_POINTER_REGNUM SP_REGNUM
 
diff --git a/gcc/config/nvptx/nvptx.h b/gcc/config/nvptx/nvptx.h
index ed72c253191..88ef45d450e 100644
--- a/gcc/config/nvptx/nvptx.h
+++ b/gcc/config/nvptx/nvptx.h
@@ -253,7 +253,7 @@ struct GTY(()) machine_function
 #undef ASM_APP_OFF
 #define ASM_APP_OFF "\t// #NO_APP \n"
 
-#define DBX_REGISTER_NUMBER(N) N
+#define DEBUGGER_REGISTER_NUMBER(N) N
 
 #define TEXT_SECTION_ASM_OP ""
 #define DATA_SECTION_ASM_OP ""
diff --git a/gcc/config/or1k/or1k.h b/gcc/config/or1k/or1k.h
index 18a526d386f..86468fc18e0 100644
--- a/gcc/config/or1k/or1k.h
+++ b/gcc/config/or1k/or1k.h
@@ -146,7 +146,7 @@
    : (X) < 24 ? ((X) - 16) * 2 + 17	\
    : ((X) - 24) * 2 + 16)
 
-#define DBX_REGISTER_NUMBER(X)  GCC_TO_HW_REGNO(X)
+#define DEBUGGER_REGISTER_NUMBER(X)  GCC_TO_HW_REGNO(X)
 
 #define REGISTER_NAMES { \
   "r0",   "r1",   "r2",   "r3",   "r4",   "r5",   "r6",   "r7",   \
diff --git a/gcc/config/pa/pa32-regs.h b/gcc/config/pa/pa32-regs.h
index 62084a50abc..76d77333046 100644
--- a/gcc/config/pa/pa32-regs.h
+++ b/gcc/config/pa/pa32-regs.h
@@ -227,7 +227,7 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
       || (GET_MODE_SIZE (MODE) == 8 * UNITS_PER_WORD			\
 	  && ((REGNO) & 7) == 3 && (REGNO) <= 19)))
 
-/* How to renumber registers for dbx and gdb.
+/* How to renumber registers for gdb.
 
    Registers 0  - 31 remain unchanged.
 
@@ -235,11 +235,11 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 
    Register 88 is mapped to 32.  */
 
-#define DBX_REGISTER_NUMBER(REGNO) \
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
   ((REGNO) <= 31 ? (REGNO) :						\
    ((REGNO) <= 87 ? (REGNO) + 40 : 32))
 
-/* We must not use the DBX register numbers for the DWARF 2 CFA column
+/* We must not use the debugger register numbers for the DWARF 2 CFA column
    numbers because that maps to numbers beyond FIRST_PSEUDO_REGISTER.
    Instead use the identity mapping.  */
 #define DWARF_FRAME_REGNUM(REG) REG
diff --git a/gcc/config/pa/pa64-regs.h b/gcc/config/pa/pa64-regs.h
index 7daf44560dd..2c45642e280 100644
--- a/gcc/config/pa/pa64-regs.h
+++ b/gcc/config/pa/pa64-regs.h
@@ -165,17 +165,17 @@ along with GCC; see the file COPYING3.  If not see
       || (GET_MODE_SIZE (MODE) == 4 * UNITS_PER_WORD			\
 	  && ((REGNO) & 3) == 3 && (REGNO) <= 23)))
 
-/* How to renumber registers for dbx and gdb.
+/* How to renumber registers for gdb.
 
    Registers 0  - 31 remain unchanged.
 
    Registers 32 - 59 are mapped to 72, 74, 76 ...
 
    Register 60 is mapped to 32.  */
-#define DBX_REGISTER_NUMBER(REGNO) \
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
   ((REGNO) <= 31 ? (REGNO) : ((REGNO) < 60 ? (REGNO - 32) * 2 + 72 : 32))
 
-/* We must not use the DBX register numbers for the DWARF 2 CFA column
+/* We must not use the debugger register numbers for the DWARF 2 CFA column
    numbers because that maps to numbers beyond FIRST_PSEUDO_REGISTER.
    Instead use the identity mapping.  */
 #define DWARF_FRAME_REGNUM(REG) REG
diff --git a/gcc/config/pdp11/pdp11.h b/gcc/config/pdp11/pdp11.h
index 1fa52e8c754..55e0625e6ea 100644
--- a/gcc/config/pdp11/pdp11.h
+++ b/gcc/config/pdp11/pdp11.h
@@ -50,7 +50,7 @@ along with GCC; see the file COPYING3.  If not see
   while (0)
 
 
-/* Generate DBX debugging information.  */
+/* Generate debugger debugging information.  */
 #define TARGET_40_PLUS		(TARGET_40 || TARGET_45)
 #define TARGET_10		(! TARGET_40_PLUS)
 
diff --git a/gcc/config/rs6000/rs6000-protos.h b/gcc/config/rs6000/rs6000-protos.h
index b3c16e7448d..9edd356f5fe 100644
--- a/gcc/config/rs6000/rs6000-protos.h
+++ b/gcc/config/rs6000/rs6000-protos.h
@@ -291,7 +291,7 @@ extern int rs6000_trampoline_size (void);
 extern alias_set_type get_TOC_alias_set (void);
 extern void rs6000_emit_prologue (void);
 extern void rs6000_emit_load_toc_table (int);
-extern unsigned int rs6000_dbx_register_number (unsigned int, unsigned int);
+extern unsigned int rs6000_debugger_register_number (unsigned int, unsigned int);
 extern void rs6000_emit_epilogue (enum epilogue_type);
 extern void rs6000_expand_split_stack_prologue (void);
 extern void rs6000_split_stack_space_check (rtx, rtx);
diff --git a/gcc/config/rs6000/rs6000.cc b/gcc/config/rs6000/rs6000.cc
index 679d9c2c2bd..cfa09fb2200 100644
--- a/gcc/config/rs6000/rs6000.cc
+++ b/gcc/config/rs6000/rs6000.cc
@@ -23637,7 +23637,7 @@ rs6000_init_dwarf_reg_sizes_extra (tree address)
      2 -- DWARF .eh_frame section  */
 
 unsigned int
-rs6000_dbx_register_number (unsigned int regno, unsigned int format)
+rs6000_debugger_register_number (unsigned int regno, unsigned int format)
 {
   /* On some platforms, we use the standard DWARF register
      numbering for .debug_info and .debug_frame.  */
diff --git a/gcc/config/rs6000/rs6000.h b/gcc/config/rs6000/rs6000.h
index ad9bf0f7358..5069725b361 100644
--- a/gcc/config/rs6000/rs6000.h
+++ b/gcc/config/rs6000/rs6000.h
@@ -795,7 +795,7 @@ enum data_align { align_abi, align_opt, align_both };
 #define FIRST_PSEUDO_REGISTER 111
 
 /* Use standard DWARF numbering for DWARF debugging information.  */
-#define DBX_REGISTER_NUMBER(REGNO) rs6000_dbx_register_number ((REGNO), 0)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) rs6000_debugger_register_number ((REGNO), 0)
 
 /* Use gcc hard register numbering for eh_frame.  */
 #define DWARF_FRAME_REGNUM(REGNO) (REGNO)
@@ -804,7 +804,7 @@ enum data_align { align_abi, align_opt, align_both };
    collected using DWARF_FRAME_REGNUM to those that should be output in
    .debug_frame and .eh_frame.  */
 #define DWARF2_FRAME_REG_OUT(REGNO, FOR_EH) \
-  rs6000_dbx_register_number ((REGNO), (FOR_EH) ? 2 : 1)
+  rs6000_debugger_register_number ((REGNO), (FOR_EH) ? 2 : 1)
 
 /* 1 for registers that have pervasive standard uses
    and are not available for the register allocator.
diff --git a/gcc/config/s390/s390.h b/gcc/config/s390/s390.h
index 2e1bc71e73a..9f118888a2b 100644
--- a/gcc/config/s390/s390.h
+++ b/gcc/config/s390/s390.h
@@ -705,7 +705,7 @@ extern const enum reg_class regclass_map[FIRST_PSEUDO_REGISTER];
 /* Define the dwarf register mapping.
    v16-v31 -> 68-83
    rX      -> X      otherwise  */
-#define DBX_REGISTER_NUMBER(regno)				\
+#define DEBUGGER_REGISTER_NUMBER(regno)				\
   (((regno) >= 38 && (regno) <= 53) ? (regno) + 30 : (regno))
 
 /* Frame registers.  */
diff --git a/gcc/config/sh/elf.h b/gcc/config/sh/elf.h
index f0fd19f8854..d9d1a7633ff 100644
--- a/gcc/config/sh/elf.h
+++ b/gcc/config/sh/elf.h
@@ -61,7 +61,7 @@ along with GCC; see the file COPYING3.  If not see
 #define LINK_EMUL_PREFIX "sh%{ml:l}elf"
 #endif
 
-#define DBX_REGISTER_NUMBER(REGNO) SH_DBX_REGISTER_NUMBER (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) SH_DEBUGGER_REGISTER_NUMBER (REGNO)
 
 #undef ASM_GENERATE_INTERNAL_LABEL
 #define ASM_GENERATE_INTERNAL_LABEL(STRING, PREFIX, NUM) \
diff --git a/gcc/config/sh/linux.h b/gcc/config/sh/linux.h
index d96d077c99e..c064f144082 100644
--- a/gcc/config/sh/linux.h
+++ b/gcc/config/sh/linux.h
@@ -111,11 +111,11 @@ along with GCC; see the file COPYING3.  If not see
    in MD_FALLBACK_FRAME_STATE_FOR and its content will be read with
    _Unwind_GetGR which uses dwarf_reg_size_table to get the size of
    the register.  So the entry of dwarf_reg_size_table corresponding to
-   this slot must be set.  To do this, we redefine DBX_REGISTER_NUMBER
+   this slot must be set.  To do this, we redefine DEBUGGER_REGISTER_NUMBER
    so as to return itself for 16.  */
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(REGNO) \
-  (((REGNO) == 16) ? 16 : SH_DBX_REGISTER_NUMBER (REGNO))
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
+  (((REGNO) == 16) ? 16 : SH_DEBUGGER_REGISTER_NUMBER (REGNO))
 
 /* Install the __sync libcalls.  */
 #undef TARGET_INIT_LIBFUNCS
diff --git a/gcc/config/sh/sh.h b/gcc/config/sh/sh.h
index 4f209d2319f..f3c3138ebf4 100644
--- a/gcc/config/sh/sh.h
+++ b/gcc/config/sh/sh.h
@@ -1654,14 +1654,14 @@ extern bool current_function_interrupt;
   fprintf ((file), "\tmov.l\t@r15+,r%d\n", (v));	\
 }
 
-/* DBX register number for a given compiler register number.  */
+/* Debugger register number for a given compiler register number.  */
 /* GDB has FPUL at 23 and FP0 at 25, so we must add one to all FP registers
    to match gdb.  */
 /* expand_builtin_init_dwarf_reg_sizes uses this to test if a
    register exists, so we should return -1 for invalid register numbers.  */
-#define DBX_REGISTER_NUMBER(REGNO) SH_DBX_REGISTER_NUMBER (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) SH_DEBUGGER_REGISTER_NUMBER (REGNO)
 
-#define SH_DBX_REGISTER_NUMBER(REGNO) \
+#define SH_DEBUGGER_REGISTER_NUMBER(REGNO) \
   (IN_RANGE ((REGNO), \
 	     (unsigned HOST_WIDE_INT) FIRST_GENERAL_REG, \
 	     FIRST_GENERAL_REG + 15U) \
diff --git a/gcc/config/visium/visium.h b/gcc/config/visium/visium.h
index e9819243728..633eaaf6c88 100644
--- a/gcc/config/visium/visium.h
+++ b/gcc/config/visium/visium.h
@@ -1491,7 +1491,7 @@ do									\
    This describes how to specify debugging information.
 
     mda is known to GDB, but not to GCC. */
-#define DBX_REGISTER_NUMBER(REGNO) \
+#define DEBUGGER_REGISTER_NUMBER(REGNO) \
   ((REGNO) > MDB_REGNUM ? (REGNO) + 1 : (REGNO))
 
 /* `DEBUGGER_AUTO_OFFSET (X)'
@@ -1500,7 +1500,7 @@ do									\
    automatic variable having address X (an RTL expression).  The
    default computation assumes that X is based on the frame-pointer
    and gives the offset from the frame-pointer.  This is required for
-   targets that produce debugging output for DBX and allow the frame-pointer
+   targets that produce debugging output for debugger and allow the frame-pointer
    to be eliminated when the `-g' options is used. */
 #define DEBUGGER_AUTO_OFFSET(X) \
   (GET_CODE (X) == PLUS ? INTVAL (XEXP (X, 1)) : 0)
diff --git a/gcc/config/xtensa/elf.h b/gcc/config/xtensa/elf.h
index 527bb4e8e27..0ba74669200 100644
--- a/gcc/config/xtensa/elf.h
+++ b/gcc/config/xtensa/elf.h
@@ -81,7 +81,7 @@ along with GCC; see the file COPYING3.  If not see
 /* Do not force "-fpic" for this target.  */
 #define XTENSA_ALWAYS_PIC 0
 
-#undef DBX_REGISTER_NUMBER
+#undef DEBUGGER_REGISTER_NUMBER
 
 /* Search for headers in $tooldir/arch/include and for libraries and
    startfiles in $tooldir/arch/lib.  */
diff --git a/gcc/config/xtensa/linux.h b/gcc/config/xtensa/linux.h
index edce618fb94..797dd500500 100644
--- a/gcc/config/xtensa/linux.h
+++ b/gcc/config/xtensa/linux.h
@@ -67,5 +67,5 @@ along with GCC; see the file COPYING3.  If not see
 /* Always enable "-fpic" for Xtensa Linux.  */
 #define XTENSA_ALWAYS_PIC 1
 
-#undef DBX_REGISTER_NUMBER
+#undef DEBUGGER_REGISTER_NUMBER
 
diff --git a/gcc/config/xtensa/uclinux.h b/gcc/config/xtensa/uclinux.h
index d47fd6313b4..7cb46bb0203 100644
--- a/gcc/config/xtensa/uclinux.h
+++ b/gcc/config/xtensa/uclinux.h
@@ -70,5 +70,5 @@ along with GCC; see the file COPYING3.  If not see
 #undef TARGET_LIBC_HAS_FUNCTION
 #define TARGET_LIBC_HAS_FUNCTION no_c99_libc_has_function
 
-#undef DBX_REGISTER_NUMBER
+#undef DEBUGGER_REGISTER_NUMBER
 
diff --git a/gcc/config/xtensa/xtensa-protos.h b/gcc/config/xtensa/xtensa-protos.h
index e020a332b03..fb0ec268003 100644
--- a/gcc/config/xtensa/xtensa-protos.h
+++ b/gcc/config/xtensa/xtensa-protos.h
@@ -71,7 +71,7 @@ extern rtx xtensa_return_addr (int, rtx);
 #endif /* RTX_CODE */
 
 extern void xtensa_setup_frame_addresses (void);
-extern int xtensa_dbx_register_number (int);
+extern int xtensa_debugger_register_number (int);
 extern long compute_frame_size (poly_int64);
 extern bool xtensa_use_return_instruction_p (void);
 extern void xtensa_expand_prologue (void);
diff --git a/gcc/config/xtensa/xtensa.cc b/gcc/config/xtensa/xtensa.cc
index b673b6764da..d67aa6ebcb7 100644
--- a/gcc/config/xtensa/xtensa.cc
+++ b/gcc/config/xtensa/xtensa.cc
@@ -2430,7 +2430,7 @@ xtensa_cannot_force_const_mem (machine_mode mode ATTRIBUTE_UNUSED, rtx x)
 /* Return the debugger register number to use for 'regno'.  */
 
 int
-xtensa_dbx_register_number (int regno)
+xtensa_debugger_register_number (int regno)
 {
   int first = -1;
 
diff --git a/gcc/config/xtensa/xtensa.h b/gcc/config/xtensa/xtensa.h
index d51658afa89..90efd822f87 100644
--- a/gcc/config/xtensa/xtensa.h
+++ b/gcc/config/xtensa/xtensa.h
@@ -216,7 +216,7 @@ along with GCC; see the file COPYING3.  If not see
 #define FIRST_PSEUDO_REGISTER 36
 
 /* Return the stabs register number to use for REGNO.  */
-#define DBX_REGISTER_NUMBER(REGNO) xtensa_dbx_register_number (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) xtensa_debugger_register_number (REGNO)
 
 /* 1 for registers that have pervasive standard uses
    and are not available for the register allocator.  */
diff --git a/gcc/defaults.h b/gcc/defaults.h
index 7c7a80e596e..c170105ed3f 100644
--- a/gcc/defaults.h
+++ b/gcc/defaults.h
@@ -429,17 +429,17 @@ see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 #endif
 #endif
 
-/* How to renumber registers for dbx and gdb.  If not defined, assume
+/* How to renumber registers for gdb.  If not defined, assume
    no renumbering is necessary.  */
 
-#ifndef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(REGNO) (REGNO)
+#ifndef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(REGNO) (REGNO)
 #endif
 
 /* The mapping from gcc register number to DWARF 2 CFA column number.
    By default, we just provide columns for all registers.  */
 #ifndef DWARF_FRAME_REGNUM
-#define DWARF_FRAME_REGNUM(REG) DBX_REGISTER_NUMBER (REG)
+#define DWARF_FRAME_REGNUM(REG) DEBUGGER_REGISTER_NUMBER (REG)
 #endif
 
 /* The mapping from dwarf CFA reg number to internal dwarf reg numbers.  */
diff --git a/gcc/doc/tm.texi b/gcc/doc/tm.texi
index 431b414cf5d..6a7f6a2327a 100644
--- a/gcc/doc/tm.texi
+++ b/gcc/doc/tm.texi
@@ -3768,7 +3768,7 @@ Define this macro if the target's representation for dwarf registers
 used in .eh_frame or .debug_frame is different from that used in other
 debug info sections.  Given a GCC hard register number, this macro
 should return the .eh_frame register number.  The default is
-@code{DBX_REGISTER_NUMBER (@var{regno})}.
+@code{DEBUGGER_REGISTER_NUMBER (@var{regno})}.
 
 @end defmac
 
@@ -9931,21 +9931,21 @@ This describes how to specify debugging information.
 @c prevent bad page break with this line
 These macros affect all debugging formats.
 
-@defmac DBX_REGISTER_NUMBER (@var{regno})
-A C expression that returns the DBX register number for the compiler
+@defmac DEBUGGER_REGISTER_NUMBER (@var{regno})
+A C expression that returns the debugger register number for the compiler
 register number @var{regno}.  In the default macro provided, the value
 of this expression will be @var{regno} itself.  But sometimes there are
-some registers that the compiler knows about and DBX does not, or vice
+some registers that the compiler knows about and debugger does not, or vice
 versa.  In such cases, some register may need to have one number in the
-compiler and another for DBX@.
+compiler and another for debugger@.
 
 If two registers have consecutive numbers inside GCC, and they can be
 used as a pair to hold a multiword value, then they @emph{must} have
-consecutive numbers after renumbering with @code{DBX_REGISTER_NUMBER}.
+consecutive numbers after renumbering with @code{DEBUGGER_REGISTER_NUMBER}.
 Otherwise, debuggers will be unable to access such a pair, because they
 expect register pairs to be consecutive in their own numbering scheme.
 
-If you find yourself defining @code{DBX_REGISTER_NUMBER} in way that
+If you find yourself defining @code{DEBUGGER_REGISTER_NUMBER} in way that
 does not preserve register pairs, then what you must do instead is
 redefine the actual register numbering scheme.
 @end defmac
@@ -9955,7 +9955,7 @@ A C expression that returns the integer offset value for an automatic
 variable having address @var{x} (an RTL expression).  The default
 computation assumes that @var{x} is based on the frame-pointer and
 gives the offset from the frame-pointer.  This is required for targets
-that produce debugging output for DBX and allow the frame-pointer to be
+that produce debugging output for debugger and allow the frame-pointer to be
 eliminated when the @option{-g} option is used.
 @end defmac
 
@@ -9985,8 +9985,7 @@ or @option{-gvms}.
 
 @defmac DEFAULT_GDB_EXTENSIONS
 Define this macro to control whether GCC should by default generate
-GDB's extended version of DBX debugging information (assuming DBX-format
-debugging information is enabled at all).  If you don't define the
+GDB's extended version of debugging information.  If you don't define the
 macro, the default is 1: always generate the extended information
 if there is any occasion to.
 @end defmac
diff --git a/gcc/doc/tm.texi.in b/gcc/doc/tm.texi.in
index de0414d6592..be7d229e3ee 100644
--- a/gcc/doc/tm.texi.in
+++ b/gcc/doc/tm.texi.in
@@ -3009,7 +3009,7 @@ Define this macro if the target's representation for dwarf registers
 used in .eh_frame or .debug_frame is different from that used in other
 debug info sections.  Given a GCC hard register number, this macro
 should return the .eh_frame register number.  The default is
-@code{DBX_REGISTER_NUMBER (@var{regno})}.
+@code{DEBUGGER_REGISTER_NUMBER (@var{regno})}.
 
 @end defmac
 
@@ -6615,21 +6615,21 @@ This describes how to specify debugging information.
 @c prevent bad page break with this line
 These macros affect all debugging formats.
 
-@defmac DBX_REGISTER_NUMBER (@var{regno})
-A C expression that returns the DBX register number for the compiler
+@defmac DEBUGGER_REGISTER_NUMBER (@var{regno})
+A C expression that returns the debugger register number for the compiler
 register number @var{regno}.  In the default macro provided, the value
 of this expression will be @var{regno} itself.  But sometimes there are
-some registers that the compiler knows about and DBX does not, or vice
+some registers that the compiler knows about and debugger does not, or vice
 versa.  In such cases, some register may need to have one number in the
-compiler and another for DBX@.
+compiler and another for debugger@.
 
 If two registers have consecutive numbers inside GCC, and they can be
 used as a pair to hold a multiword value, then they @emph{must} have
-consecutive numbers after renumbering with @code{DBX_REGISTER_NUMBER}.
+consecutive numbers after renumbering with @code{DEBUGGER_REGISTER_NUMBER}.
 Otherwise, debuggers will be unable to access such a pair, because they
 expect register pairs to be consecutive in their own numbering scheme.
 
-If you find yourself defining @code{DBX_REGISTER_NUMBER} in way that
+If you find yourself defining @code{DEBUGGER_REGISTER_NUMBER} in way that
 does not preserve register pairs, then what you must do instead is
 redefine the actual register numbering scheme.
 @end defmac
@@ -6639,7 +6639,7 @@ A C expression that returns the integer offset value for an automatic
 variable having address @var{x} (an RTL expression).  The default
 computation assumes that @var{x} is based on the frame-pointer and
 gives the offset from the frame-pointer.  This is required for targets
-that produce debugging output for DBX and allow the frame-pointer to be
+that produce debugging output for debugger and allow the frame-pointer to be
 eliminated when the @option{-g} option is used.
 @end defmac
 
@@ -6669,8 +6669,7 @@ or @option{-gvms}.
 
 @defmac DEFAULT_GDB_EXTENSIONS
 Define this macro to control whether GCC should by default generate
-GDB's extended version of DBX debugging information (assuming DBX-format
-debugging information is enabled at all).  If you don't define the
+GDB's extended version of debugging information.  If you don't define the
 macro, the default is 1: always generate the extended information
 if there is any occasion to.
 @end defmac
diff --git a/gcc/except.cc b/gcc/except.cc
index 7d7ce40c846..e4a78bcb4ae 100644
--- a/gcc/except.cc
+++ b/gcc/except.cc
@@ -2175,7 +2175,7 @@ expand_builtin_eh_return_data_regno (tree exp)
 #ifdef DWARF_FRAME_REGNUM
   iwhich = DWARF_FRAME_REGNUM (iwhich);
 #else
-  iwhich = DBX_REGISTER_NUMBER (iwhich);
+  iwhich = DEBUGGER_REGISTER_NUMBER (iwhich);
 #endif
 
   return GEN_INT (iwhich);

diff --git a/gcc/config/frv/frv.h b/gcc/config/frv/frv.h
index 8cd67f75b09..f4179805392 100644
--- a/gcc/config/frv/frv.h
+++ b/gcc/config/frv/frv.h
@@ -1737,24 +1737,24 @@ fprintf (STREAM, "\t.word .L%d\n", VALUE)
 
 /* Macros Affecting all Debug Formats.  */
 
 /* A C expression that returns the DBX register number for the compiler
    register number REGNO.  In simple cases, the value of this expression may be
    REGNO itself.  But sometimes there are some registers that the compiler
-   knows about and DBX does not, or vice versa.  In such cases, some register
-   may need to have one number in the compiler and another for DBX.
+   knows about and debugger does not, or vice versa.  In such cases, some register
+   may need to have one number in the compiler and another for debugger.
 
    If two registers have consecutive numbers inside GCC, and they can be
    used as a pair to hold a multiword value, then they *must* have consecutive
-   numbers after renumbering with `DBX_REGISTER_NUMBER'.  Otherwise, debuggers
+   numbers after renumbering with `DEBUGGER_REGISTER_NUMBER'.  Otherwise, debuggers
    will be unable to access such a pair, because they expect register pairs to
    be consecutive in their own numbering scheme.
 
-   If you find yourself defining `DBX_REGISTER_NUMBER' in way that does not
+   If you find yourself defining `DEBUGGER_REGISTER_NUMBER' in way that does not
    preserve register pairs, then what you must do instead is redefine the
    actual register numbering scheme.
 
    This declaration is required.  */
-#define DBX_REGISTER_NUMBER(REGNO) (REGNO)
+#define DEBUGGER_REGISTER_NUMBER(REGNO) (REGNO)
 
 #undef  PREFERRED_DEBUGGING_TYPE
 #define PREFERRED_DEBUGGING_TYPE DWARF2_DEBUG
@@ -1737,24 +1737,24 @@ fprintf (STREAM, "\t.word .L%d\n", VALUE)
 /* Macros Affecting all Debug Formats.  */
 
-/* A C expression that returns the DBX register number for the compiler
+/* A C expression that returns the debugger register number for the compiler
    register number REGNO.  In simple cases, the value of this expression may be
    REGNO itself.  But sometimes there are some registers that the compiler
diff --git a/gcc/config/i386/vxworks.h b/gcc/config/i386/vxworks.h
index 3b8eb6f3a59..20397841e6d 100644
--- a/gcc/config/i386/vxworks.h
+++ b/gcc/config/i386/vxworks.h
@@ -54,12 +54,12 @@ along with GCC; see the file COPYING3.  If not see
 
 #endif
 
 /* Provide our target specific DBX_REGISTER_NUMBER.  VxWorks relies on
    the SVR4 numbering.  */
 
-#undef DBX_REGISTER_NUMBER
-#define DBX_REGISTER_NUMBER(n) \
-  (TARGET_64BIT ? dbx64_register_map[n] : svr4_dbx_register_map[n])
+#undef DEBUGGER_REGISTER_NUMBER
+#define DEBUGGER_REGISTER_NUMBER(n) \
+  (TARGET_64BIT ? debugger64_register_map[n] : svr4_debugger_register_map[n])
 
 /* CPU macro definitions, ordered to account for VxWorks 7 not
    supporting CPUs older than PENTIUM4 since SR0650.  */
@@ -54,12 +54,12 @@ along with GCC; see the file COPYING3.  If not see
 #endif
 
-/* Provide our target specific DBX_REGISTER_NUMBER.  VxWorks relies on
+/* Provide our target specific DEBUGGER_REGISTER_NUMBER.  VxWorks relies on
    the SVR4 numbering.  */
 
diff --git a/gcc/dwarf2out.cc b/gcc/dwarf2out.cc
index 9e2fa9681a0..7fed0d98dc8 100644
--- a/gcc/dwarf2out.cc
+++ b/gcc/dwarf2out.cc
@@ -3850,7 +3850,7 @@ static int decl_quals (const_tree);
 static dw_die_ref modified_type_die (tree, int, bool, dw_die_ref);
 static dw_die_ref generic_parameter_die (tree, tree, bool, dw_die_ref);
 static dw_die_ref template_parameter_pack_die (tree, tree, dw_die_ref);
-static unsigned int dbx_reg_number (const_rtx);
+static unsigned int debugger_reg_number (const_rtx);
 static void add_loc_descr_op_piece (dw_loc_descr_ref *, int);
 static dw_loc_descr_ref reg_loc_descriptor (rtx, enum var_init_status);
 static dw_loc_descr_ref one_reg_loc_descriptor (unsigned int,
@@ -14169,10 +14169,10 @@ template_parameter_pack_die (tree parm_pack,
   return die;
 }
 
 /* Return the DBX register number described by a given RTL node.  */
 
 static unsigned int
-dbx_reg_number (const_rtx rtl)
+debugger_reg_number (const_rtx rtl)
 {
   unsigned regno = REGNO (rtl);
 
@@ -14187,7 +14187,7 @@ dbx_reg_number (const_rtx rtl)
     }
 #endif
 
-  regno = DBX_REGISTER_NUMBER (regno);
+  regno = DEBUGGER_REGISTER_NUMBER (regno);
   gcc_assert (regno != INVALID_REGNUM);
   return regno;
 }
@@ -14250,10 +14250,10 @@ reg_loc_descriptor (rtx rtl, enum var_init_status initialized)
     return multiple_reg_loc_descriptor (rtl, regs, initialized);
   else
     {
-      unsigned int dbx_regnum = dbx_reg_number (rtl);
-      if (dbx_regnum == IGNORED_DWARF_REGNUM)
+      unsigned int debugger_regnum = debugger_reg_number (rtl);
+      if (debugger_regnum == IGNORED_DWARF_REGNUM)
 	return 0;
-      return one_reg_loc_descriptor (dbx_regnum, initialized);
+      return one_reg_loc_descriptor (debugger_regnum, initialized);
     }
 }
 
@@ -14302,7 +14302,7 @@ multiple_reg_loc_descriptor (rtx rtl, rtx regs,
 	}
 #endif
 
-      gcc_assert ((unsigned) DBX_REGISTER_NUMBER (reg) == dbx_reg_number (rtl));
+      gcc_assert ((unsigned) DEBUGGER_REGISTER_NUMBER (reg) == debugger_reg_number (rtl));
       nregs = REG_NREGS (rtl);
 
       /* At present we only track constant-sized pieces.  */
@@ -14315,7 +14315,7 @@ multiple_reg_loc_descriptor (rtx rtl, rtx regs,
 	{
 	  dw_loc_descr_ref t;
 
-	  t = one_reg_loc_descriptor (DBX_REGISTER_NUMBER (reg),
+	  t = one_reg_loc_descriptor (DEBUGGER_REGISTER_NUMBER (reg),
 				      VAR_INIT_STATUS_INITIALIZED);
 	  add_loc_descr (&loc_result, t);
 	  add_loc_descr_op_piece (&loc_result, size);
@@ -14337,7 +14337,7 @@ multiple_reg_loc_descriptor (rtx rtl, rtx regs,
     {
       dw_loc_descr_ref t;
 
-      t = one_reg_loc_descriptor (dbx_reg_number (XVECEXP (regs, 0, i)),
+      t = one_reg_loc_descriptor (debugger_reg_number (XVECEXP (regs, 0, i)),
 				  VAR_INIT_STATUS_INITIALIZED);
       add_loc_descr (&loc_result, t);
       add_loc_descr_op_piece (&loc_result, size);
@@ -15995,7 +15995,7 @@ mem_loc_descriptor (rtx rtl, machine_mode mode,
 	      ))
 	{
 	  dw_die_ref type_die;
-	  unsigned int dbx_regnum;
+	  unsigned int debugger_regnum;
 
 	  if (dwarf_strict && dwarf_version < 5)
 	    break;
@@ -16005,11 +16005,11 @@ mem_loc_descriptor (rtx rtl, machine_mode mode,
 	  if (type_die == NULL)
 	    break;
 
-	  dbx_regnum = dbx_reg_number (rtl);
-	  if (dbx_regnum == IGNORED_DWARF_REGNUM)
+	  debugger_regnum = debugger_reg_number (rtl);
+	  if (debugger_regnum == IGNORED_DWARF_REGNUM)
 	    break;
 	  mem_loc_result = new_loc_descr (dwarf_OP (DW_OP_regval_type),
-					  dbx_regnum, 0);
+					  debugger_regnum, 0);
 	  mem_loc_result->dw_loc_oprnd2.val_class = dw_val_class_die_ref;
 	  mem_loc_result->dw_loc_oprnd2.v.val_die_ref.die = type_die;
 	  mem_loc_result->dw_loc_oprnd2.v.val_die_ref.external = 0;
@@ -16280,10 +16280,10 @@ mem_loc_descriptor (rtx rtl, machine_mode mode,
 				      VOIDmode, VAR_INIT_STATUS_INITIALIZED);
 	  else
 	    {
-              unsigned int dbx_regnum = dbx_reg_number (ENTRY_VALUE_EXP (rtl));
-	      if (dbx_regnum == IGNORED_DWARF_REGNUM)
+	      unsigned int debugger_regnum = debugger_reg_number (ENTRY_VALUE_EXP (rtl));
+	      if (debugger_regnum == IGNORED_DWARF_REGNUM)
 		return NULL;
-	      op0 = one_reg_loc_descriptor (dbx_regnum,
+	      op0 = one_reg_loc_descriptor (debugger_regnum,
 					    VAR_INIT_STATUS_INITIALIZED);
 	    }
 	}
@@ -14169,10 +14169,10 @@ template_parameter_pack_die (tree parm_pack,
 }
 
-/* Return the DBX register number described by a given RTL node.  */
+/* Return the debugger register number described by a given RTL node.  */
 
 static unsigned int